<?php namespace THINKAIPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Text_Stroke;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Feature_Services extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'thinkai_feature_services';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Thinkai Feature Services', 'thinkai' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-banner';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'thinkai' ];
    }
	
    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'feature_services',
            [
                'label' => esc_html__( 'Thinkai Feature Services', 'thinkai' ),
            ]
        );
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'thinkai' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'thinkai'),
					'2' => esc_html__( 'Style Two ', 'thinkai'),
				),
			]
		);
		
		//Vertical Client Carousel Repeater
		$repeater = new Repeater();
		$repeater->add_control(
			'shape_image',
			[
				'label' => esc_html__( 'BG Shape Image', 'thinkai' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$repeater->add_control(
			'title',
			[
				'label'       => __( 'Title', 'thinkai' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'thinkai' ),
			]
		);
		//Link
		$repeater->add_control(
			'link_option',
			[
				'label'   => esc_html__( 'Select link Option', 'thinkai' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'extranal',
				'options' => array(
					'extranal' => esc_html__( 'Extranal ', 'thinkai'),
					'page' => esc_html__( 'Page ', 'thinkai'),
				),
			]
		);		
		$repeater->add_control(
			'link',
			[
				'label' => __( 'External Link', 'thinkai' ),
				'type' => Controls_Manager::URL,
				'label_block' => true, 
				'placeholder' => __( 'https://your-link.com', 'thinkai' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
				'condition'   => [
					'link_option' => 'extranal'
				]
			]
		);		
		$repeater->add_control(
			'page_select',
			[
				'label'   => esc_html__( 'Select Page', 'thinkai' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT2,
				'default' => 'extranal',
				'options' => thinkai_page_list(),
				'condition'   => [
					'link_option' => 'page'
				]
			]
		);
		//Icons
		$repeater->add_control(
			'icon',
			[
				'label' => esc_html__('Enter The icons', 'thinkai'),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'icon-medal',
					'library' => 'solid',
				],
			]			
		);
		//text	
		$repeater->add_control(
			'text',
			[
				'label'       => __( 'Text', 'thinkai' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text', 'thinkai' ),
			]
		);
		$this->add_control(
			'feature',
			[
				'label'                 => __('Add Slide Item', 'thinkai'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'title_field' => '{{{ title }}}',
				'condition'   => [
					'layout_control' => '1',
				]
			]
		);
		
		//Vertical Client Carousel Repeater
		$repeater = new Repeater();
		$repeater->add_control(
			'bg_shape_image',
			[
				'label' => esc_html__( 'BG Shape Image', 'thinkai' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$repeater->add_control(
			'feature_image',
			[
				'label' => esc_html__( 'Feature Image', 'thinkai' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$repeater->add_control(
			'title',
			[
				'label'       => __( 'Title', 'thinkai' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Title', 'thinkai' ),
			]
		);
		//text	
		$repeater->add_control(
			'text',
			[
				'label'       => __( 'Text', 'thinkai' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Text', 'thinkai' ),
			]
		);
		//Button Title
		$repeater->add_control(
			'btn_title',
			[
				'label'       => __( 'Button Title', 'thinkai' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title', 'thinkai' ),
			]
		);
		//Link
		$repeater->add_control(
			'link_option',
			[
				'label'   => esc_html__( 'Select link Option', 'thinkai' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'extranal',
				'options' => array(
					'extranal' => esc_html__( 'Extranal ', 'thinkai'),
					'page' => esc_html__( 'Page ', 'thinkai'),
				),
			]
		);		
		$repeater->add_control(
			'link',
			[
				'label' => __( 'External Link', 'thinkai' ),
				'type' => Controls_Manager::URL,
				'label_block' => true, 
				'placeholder' => __( 'https://your-link.com', 'thinkai' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
				'condition'   => [
					'link_option' => 'extranal'
				]
			]
		);		
		$repeater->add_control(
			'page_select',
			[
				'label'   => esc_html__( 'Select Page', 'thinkai' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT2,
				'default' => 'extranal',
				'options' => thinkai_page_list(),
				'condition'   => [
					'link_option' => 'page'
				]
			]
		);
		$this->add_control(
			'feature_v2',
			[
				'label'                 => __('Add Magic Item', 'thinkai'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'title_field' => '{{{ title }}}',
				'condition'   => [
					'layout_control' => '2',
				],
				'default' => [
					[
						'title' => esc_html__( 'Live Action', 'thinkai' ),
						'text' => esc_html__( 'Holds in these matters this principle...', 'thinkai' ),
						'btn_title' => esc_html__( 'Read More', 'thinkai' ),
						'link' => esc_html__( '#', 'thinkai' ),
					],
					[
						'title' => esc_html__( 'Motion Graphics', 'thinkai' ),
						'text' => esc_html__( 'Obligations of business it frequently...', 'thinkai' ),
						'btn_title' => esc_html__( 'Read More', 'thinkai' ),
						'link' => esc_html__( '#', 'thinkai' ),
					],
					[
						'title' => esc_html__( 'Cartoon', 'thinkai' ),
						'text' => esc_html__( 'Holds in these matters this principle...', 'thinkai' ),
						'btn_title' => esc_html__( 'Read More', 'thinkai' ),
						'link' => esc_html__( '#', 'thinkai' ),
					],
				],
			]
		);
		$this->end_controls_section();
		
		/************************************************************************
									Tab Style Start
		*************************************************************************/		
		
		//Title Style		
		$this->start_controls_section(
			'title_style',
			[
				'label' => esc_html__( 'Title Style Settings', 'thinkai' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);		
		$this->add_responsive_control(
            'title__margin',
            [
                'label'      => esc_html__( 'Margin', 'thinkai' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .te-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
                'separator'  => 'before',
            ]
        );		
        $this->add_responsive_control(
            'title_padding',
            [
                'label'      => esc_html__( 'Padding', 'thinkai' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .te-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
                'separator'  => 'before',
            ]
        );		
		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Text Color', 'thinkai' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .te-title' => 'color: {{VALUE}} !important;',
					'{{WRAPPER}} .te-title a' => 'color: {{VALUE}} !important;',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => __('Typography', 'thinkai'),
				'selector' => '{{WRAPPER}} .te-title,
								{{WRAPPER}} .te-title a',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Stroke::get_type(),
			[
				'name' => 'title_text_stroke',
				'selector' => '{{WRAPPER}} .te-title',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'title_text_shadow',
				'selector' => '{{WRAPPER}} .te-title',
			]
		);
		$this->end_controls_section();
		
		//Text Style		
		$this->start_controls_section(
			'text_style',
			[
				'label' => esc_html__( 'Text Style Settings', 'thinkai' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);		
		$this->add_responsive_control(
            'text__margin',
            [
                'label'      => esc_html__( 'Margin', 'thinkai' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .te-text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
                'separator'  => 'before',
            ]
        );		
        $this->add_responsive_control(
            'text_padding',
            [
                'label'      => esc_html__( 'Padding', 'thinkai' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .te-text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
                'separator'  => 'before',
            ]
        );			
		$this->add_control(
			'text_color',
			[
				'label' => esc_html__( 'Text Color', 'thinkai' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .te-text' => 'color: {{VALUE}} !important;',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_typography',
				'label' => __('Typography', 'thinkai'),
				'selector' => '{{WRAPPER}} .te-text',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Stroke::get_type(),
			[
				'name' => 'text_text_stroke',
				'selector' => '{{WRAPPER}} .te-text',
			]
		);
		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name' => 'text_text_shadow',
				'selector' => '{{WRAPPER}} .te-text',
			]
		);
		$this->end_controls_section();
			
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
		$layout = $settings[ 'layout_control' ];
	?>
    
    
	<?php if($layout == '2') : ?>
	
    <!--Start Video Types Style1-->
    <section class="video-types-style1 p-0 m-0">
        <div class="container">
            <ul class="row">
				<?php 
					foreach ( $settings['feature_v2'] as $key => $item ) { 
					
					$page = $item['link_option'];
					$page_select = $item[ 'page_select' ];
					$ext_url = $item[ 'link' ];
					
					if( $page == 'page' ){
						$mount_link = get_page_link( $page_select );
					}else{
						$mount_link = $ext_url['url'];
						$target = $ext_url['is_external'] ? ' target="_blank"' : '';
						$nofollow = $ext_url['nofollow'] ? ' rel="nofollow"' : '';
					}
				?>
                <!--Start Video Types Style1 Single-->
                <li class="col-xl-4 col-lg-4">
                    <div class="video-types-style1__single">
                        <div class="video-types-style1__single-img-box">
                            <div class="video-types-style1__single-img-box__bg float-bob-y"
                                style="background-image: url(<?php echo esc_url(wp_get_attachment_url($item['bg_shape_image']['id'])); ?>);">
                            </div>
                            <div class="inner">
                                <img src="<?php echo esc_url(wp_get_attachment_url($item['feature_image']['id'])); ?>" alt="<?php bloginfo( 'name' ); ?>">
                            </div>
                        </div>
                        <div class="video-types-style1__single-content-box">
                            <div class="title-box">
                                <h3 class="te-title"><a href="<?php echo esc_url( $mount_link );?>" <?php if( $page == 'extranal' ) echo esc_attr( $target );?> <?php if( $page == 'extranal' ) echo esc_attr( $nofollow );?>><?php echo wp_kses($item['title'], true); ?></a></h3>
                                <p class="te-text"><?php echo wp_kses($item['text'], true); ?></p>
                            </div>
                            <div class="btn-box">
                                <a href="<?php echo esc_url( $mount_link );?>" <?php if( $page == 'extranal' ) echo esc_attr( $target );?> <?php if( $page == 'extranal' ) echo esc_attr( $nofollow );?>>
                                    <span class="icon-right-arrow1"></span>
                                    <?php echo wp_kses($item['btn_title'], true); ?>
                                </a>
                            </div>
                        </div>
                    </div>
                </li>
                <!--End Video Types Style1 Single-->
                <?php } ?>
            </ul>
        </div>
    </section>
    <!--End Video Types Style1-->
    
    <?php else: ?>
    
    <!--Start Features Style3-->
    <section class="features-style3 p-0 m-0">
        <div class="container">
            <ul class="features-style3__inner">
                <?php 
					foreach ( $settings['feature'] as $key => $item ) { 
					
					$icon = $item['icon'];
					
					$page = $item['link_option'];
					$page_select = $item[ 'page_select' ];
					$ext_url = $item[ 'link' ];
					
					if( $page == 'page' ){
						$mount_link = get_page_link( $page_select );
					}else{
						$mount_link = $ext_url['url'];
						$target = $ext_url['is_external'] ? ' target="_blank"' : '';
						$nofollow = $ext_url['nofollow'] ? ' rel="nofollow"' : '';
					}
				?>
                <!--Single Features Style3-->
                <li>
                    <div class="features-style3__single">
                        <div class="title-box">
                            <h3 class="te-title"><a href="<?php echo esc_url( $mount_link );?>" <?php if( $page == 'extranal' ) echo esc_attr( $target );?> <?php if( $page == 'extranal' ) echo esc_attr( $nofollow );?>><?php echo wp_kses($item['title'], true); ?></a></h3>
                        </div>
                        <?php if($icon || $item['shape_image']){ ?>
                        <div class="icon-box text-center">
                            <?php
								$icon = str_replace( "icon ",  "",  $item['icon']);
								if( !empty( $icon ) ):?>
								<?php \Elementor\Icons_Manager::render_icon( $icon ); ?>
							<?php else:?>
								<span class="icon-standard"></span>
							<?php endif;?>
                            
							<?php if($item['shape_image']){ ?>
                            <div class="icon-box__shape1">
                                <img src="<?php echo esc_url(wp_get_attachment_url($item['shape_image']['id'])); ?>" alt="<?php bloginfo( 'name' ); ?>">
                            </div>
                            <?php } ?>
                        </div>
                        <?php } ?>
                        
                        <div class="text">
                            <p class="te-text"><?php echo wp_kses($item['text'], true); ?></p>
                        </div>
                    </div>
                </li>
                <!--End Features Style3-->
                <?php } ?>
            </ul>
        </div>
    </section>
    <!--End Features Style3-->
    <?php endif; ?> 
      
    <?php
    }
}
