<?php namespace THINKAIPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Text_Stroke;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Float_Image extends Widget_Base {
	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'thinkai_float_image';
	}
	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Thinkai Float Image', 'thinkai' );
	}
	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-image-hotspot';
	}
	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'thinkai' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'float_image',
			[
				'label' => esc_html__( 'Float Image', 'thinkai' ),
			]
		);
				
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'thinkai' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'thinkai'),
					'2' => esc_html__( 'Style Two ', 'thinkai'),
					'3' => esc_html__( 'Style Three ', 'thinkai'),
					'4' => esc_html__( 'Style Four ', 'thinkai'),
					'5' => esc_html__( 'Style Five ', 'thinkai'),
					'6' => esc_html__( 'Style Six ', 'thinkai'),
				),
			]
		);
		
		//Curved Title	
		$this->add_control(
			'curved_title',
			[
				'label'       => __( 'Curved Text', 'thinkai' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'default' => esc_html__( 'Making ai image is safe & easy with thinkai', 'thinkai' ),
				'condition'   => [
					'layout_control' => '1'
				]
			]
		);
		$this->add_control(
			'bg_shape_image',
			[
				'label' => esc_html__( 'BG Shape Image', 'thinkai' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition'   => [
					'layout_control' => '3',
				]
			]
		);
		$this->add_control(
			'feature_image',
			[
				'label' => esc_html__( 'Feature Image', 'thinkai' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition'   => [
					'layout_control' => ['1','2','3','4','5','6']
				]
			]
		);
		//Description
		$this->add_control(
			'founded_text',
			[
				'label'       => __( 'Founded Text', 'thinkai' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'default' => esc_html__( '2010 founded', 'thinkai' ),
				'condition'   => [
					'layout_control' => '1'
				]
			]
		);
		$this->end_controls_section();
					
    }
	
	
	/**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
	?> 
    
    <?php if($settings['layout_control'] == '6') :?>
	
    <div class="service-details__img-box p-0 m-0">
        <div class="single-img-box p-0 m-0">
            <img src="<?php echo esc_url(wp_get_attachment_url($settings['feature_image']['id'])); ?>" alt="<?php bloginfo( 'name' ); ?>">
        </div>
    </div>
    
	<?php elseif($settings['layout_control'] == '5') :?>
    
    <div class="Intro-style2__img js-tilt">
        <div class="inner">
            <img src="<?php echo esc_url(wp_get_attachment_url($settings['feature_image']['id'])); ?>" alt="<?php bloginfo( 'name' ); ?>">
        </div>
    </div>
	
	<?php elseif($settings['layout_control'] == '4') :?>
    
    <div class="about-style5__img-box">
        <img src="<?php echo esc_url(wp_get_attachment_url($settings['feature_image']['id'])); ?>" alt="<?php bloginfo( 'name' ); ?>">
    </div>
    
    <?php elseif($settings['layout_control'] == '3') :?>
    <div class="about-style2__dashboard">
        <div class="shape1">
            <img class="float-bob-x" src="<?php echo esc_url(wp_get_attachment_url($settings['bg_shape_image']['id'])); ?>" alt="<?php bloginfo( 'name' ); ?>">
        </div>
        <div class="inner">
            <img src="<?php echo esc_url(wp_get_attachment_url($settings['feature_image']['id'])); ?>" alt="<?php bloginfo( 'name' ); ?>">
        </div>
    </div>
	
	<?php elseif($settings['layout_control'] == '2') :?>
	
    <div class="about-style1__content-box-inner">
        <div class="img-box">
            <img src="<?php echo esc_url(wp_get_attachment_url($settings['feature_image']['id'])); ?>" alt="<?php bloginfo( 'name' ); ?>">
        </div>
    </div>
    
	<?php else: ?>
    
    <div class="about-style1__img-box">
        <?php if($settings['curved_title']){ ?>
        <div class="round-text">
            <div class="curved-circle">
                <?php echo wp_kses($settings['curved_title'], true); ?>
            </div>
        </div>
        <?php } ?>
        
		<?php if($settings['feature_image']){ ?>
        <div class="inner">
            <img src="<?php echo esc_url(wp_get_attachment_url($settings['feature_image']['id'])); ?>" alt="<?php bloginfo( 'name' ); ?>">
        </div>
        <?php } ?>
        
        <?php if($settings['founded_text']){ ?>
        <div class="text-box">
            <p><?php echo wp_kses($settings['founded_text'], true); ?></p>
            <div class="round"></div>
        </div>
        <?php } ?>
    </div>
        
    <?php endif; ?>  
    
    <?php 
	}
}