<?php namespace THINKAIPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Text_Stroke;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Google_Review extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'thinkai_google_review';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Thinkai Google Review', 'thinkai' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-gallery-grid';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'thinkai' ];
    }
		
    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(    
            'google_review',
            [
                'label' => esc_html__( 'Thinkai Google Review', 'thinkai' ),
            ]
        );	
		
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'thinkai' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'thinkai'),
					'2' => esc_html__( 'Style Two ', 'thinkai'),
				),
			]
		);
		
		//Review  Title
		$this->add_control(
			'review_title',
			[
				'label'       => __( 'Review Title', 'thinkai' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'default' => esc_html__( 'Google Reviews', 'thinkai' ),
			]
		);
		//Rating
		$this->add_control(
			'rating',
			[
				'label'   => esc_html__( 'Total Rating', 'thinkai' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'One Star ', 'thinkai'),
					'2' => esc_html__( 'Two Star ', 'thinkai'),
					'3' => esc_html__( 'Three Star ', 'thinkai'),
					'4' => esc_html__( 'Four Star ', 'thinkai'),
					'5' => esc_html__( 'Five Star ', 'thinkai'),
				),
			]
		);		
		//Total Title
		$this->add_control(
			'total_rating',
			[
				'label'       => __( 'Total Rating Average', 'thinkai' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'default' => esc_html__( '4.9/5.0', 'thinkai' ),
			]
		);
		//rating_description
		$this->add_control(
			'rating_description',
			[
				'label'       => __( 'Description', 'thinkai' ),
				'type'        => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'default' => esc_html__( '(from 20k reviews)', 'thinkai' ),
			]
		);
		
		
		$this->end_controls_section();
	}

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
		$layout = $settings[ 'layout_control' ];
	?>
	
    <?php if($layout == '2') : ?>
    
    
    <?php else: ?>
    
    <!--Start Google Reviews Style1-->
    <section class="google-reviews-style1">
        <div class="container">
            <div class="google-reviews-style1__inner">
                <?php if($settings['review_title']){ ?>
                <div class="google-reviews">
                    <div class="icon-box">
                        <span class="icon-google"><span class="path1"></span><span class="path2"></span><span
                                class="path3"></span><span class="path4"></span><span class="path5"></span><span
                                class="path6"></span></span>
                    </div>
                    <div class="text">
                        <p><?php echo wp_kses($settings['review_title'], true); ?></p>
                    </div>
                </div>
                <?php } ?>
                <div class="review-box">
                    <ul>
                        <?php
							$ratting = $settings['rating']; 
							for ($x = 1; $x <= 5; $x++) {
							if($x <= $ratting) echo '<li><i class="fa fa-star"></i></li>'; else echo '<li><i class="fa fa-star-half-alt"></i></li>'; 
							}
						?>
                    </ul>
                </div>
                <div class="text-box">
                    <h2><?php echo wp_kses($settings['total_rating'], true); ?> <span> <?php echo wp_kses($settings['rating_description'], true); ?></span></h2>
                </div>

            </div>
        </div>
    </section>
    <!--End Google Reviews Style1-->
   
    <?php endif; ?>
    
	<?php
    }
}
