<?php namespace THINKAIPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Text_Stroke;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Marquee_Text extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'thinkai_marquee_text';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Thinkai Marquee Text', 'thinkai' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-gallery-grid';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'thinkai' ];
    }
		
    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(    
            'marquee_text',
            [
                'label' => esc_html__( 'Thinkai Marquee Text', 'thinkai' ),
            ]
        );	
		
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'thinkai' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'thinkai'),
					'2' => esc_html__( 'Style Two ', 'thinkai'),
					'3' => esc_html__( 'Style Three ', 'thinkai'),
					'4' => esc_html__( 'Style Four ', 'thinkai'),
					'5' => esc_html__( 'Style Five ', 'thinkai'),
				),
			]
		);
		
		//Title
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'thinkai' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'default' => esc_html__( 'First Step', 'thinkai' ),
				'condition'   => [
					'layout_control' => '4',
				]
			]
		);
		
		//Monthly Plan Table		
		$repeater = new Repeater();	
		$repeater->add_control(
			'features_list',
			[
				'label'       => __( 'Feature List', 'thinkai' ),
				'type'        => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Feature List', 'thinkai' ),
			]
		);
		$this->add_control(
			'list',
			[
				'label'                 => __('Add Marquee List', 'thinkai'),
				'type'                  => Controls_Manager::REPEATER,
				'fields'                => $repeater->get_controls(),
				'condition'   => [
					'layout_control' => ['1','2','3','5']
				]
			]
		);
		//Mailchimp Form Url
		$this->add_control(
			'mailchimp_form_url',
			[
				'label'       => __( 'MailChimp Form Url', 'thinkai' ),
				'type'        => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter MailChimp Form Url', 'thinkai' ),
				'condition'   => [
					'layout_control' => '5',
				]
			]
		);
		
		
		//Feature List V1		
		$this->add_control(
			'features_list',
			[
				'label'       => __( 'Feature List', 'thinkai' ),
				'type'        => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Feature List', 'thinkai' ),
				'condition'   => [
					'layout_control' => '4'
				]
			]
		);
		
		//Marquee Text V2
		$this->add_control(
            'show_marquee_text_v2',
            [
                'label'        => esc_html__( 'Enable Marque Text V2', 'thinkai' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'thinkai' ),
                'label_off'    => esc_html__( 'Off', 'thinkai' ),
                'return_value' => 'yes',
                'default'      => 'no',
				'condition'   => [
					'layout_control' => '4',
				]
            ]
        );
		//Pattern Image
		$this->add_control(
			'pattern_img_v1',
			[
				'label' => __( 'Pattern Image', 'thinkai' ),
				'type' => Controls_Manager::MEDIA,	
				'default' => ['url' => Utils::get_placeholder_image_src(),],
				'condition'   => [
					'show_marquee_text_v2' => 'yes',
					'layout_control' => '4',
				]
			]
		);		
		//Title
		$this->add_control(
			'title_v2',
			[
				'label'       => __( 'Title', 'thinkai' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'default' => esc_html__( 'Second Step', 'thinkai' ),
				'condition'   => [
					'show_marquee_text_v2' => 'yes',
					'layout_control' => '4',
				]
			]
		);
		
		//Feature List V2		
		$this->add_control(
			'features_list_v2',
			[
				'label'       => __( 'Feature List', 'thinkai' ),
				'type'        => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Feature List', 'thinkai' ),
				'condition'   => [
					'show_marquee_text_v2' => 'yes',
					'layout_control' => '4'
				]
			]
		);
		
		//Marquee Text V3
		$this->add_control(
            'show_marquee_text_v3',
            [
                'label'        => esc_html__( 'Enable Marque Text V3', 'thinkai' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'thinkai' ),
                'label_off'    => esc_html__( 'Off', 'thinkai' ),
                'return_value' => 'yes',
                'default'      => 'no',
				'condition'   => [
					'layout_control' => '4',
				]
            ]
        );
		//Pattern Image
		$this->add_control(
			'pattern_img_v2',
			[
				'label' => __( 'Pattern Image', 'thinkai' ),
				'type' => Controls_Manager::MEDIA,	
				'default' => ['url' => Utils::get_placeholder_image_src(),],
				'condition'   => [
					'show_marquee_text_v3' => 'yes',
					'layout_control' => '4',
				]
			]
		);		
		//Title
		$this->add_control(
			'title_v3',
			[
				'label'       => __( 'Title', 'thinkai' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'default' => esc_html__( 'Third Step', 'thinkai' ),
				'condition'   => [
					'show_marquee_text_v3' => 'yes',
					'layout_control' => '4',
				]
			]
		);
		
		//Feature List V3		
		$this->add_control(
			'features_list_v3',
			[
				'label'       => __( 'Feature List', 'thinkai' ),
				'type'        => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Feature List', 'thinkai' ),
				'condition'   => [
					'show_marquee_text_v2' => 'yes',
					'layout_control' => '4'
				]
			]
		);
		
		$this->end_controls_section();			
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
		$layout = $settings[ 'layout_control' ];
	?>
	
	<?php if($layout == '5') : ?>
    
	<!--Start Subscribe Style2-->
    <section class="subscribe-style2">        
        <div class="scrolling-text-style1">
            <div class="inner">
                <ul class="clearfix marquee_mode">
                	
                    <?php 
						foreach ($settings['list'] as $keys => $items){
						
						$features_list = $items['features_list'];
						if(!empty($features_list)){
						$features_list = explode("\n", ($features_list)); 
					?>
					<li class="is-animetion">
						<?php foreach($features_list as $features): ?>
						<span><?php echo wp_kses($features, true); ?></span>
						<?php endforeach; ?>
					</li>
					<?php } } ?>

                </ul>
            </div>
        </div>
        <?php if($settings['mailchimp_form_url']){ ?>
        <div class="container">
            <div class="subscribe-style2__form">
                <div class="newsletter-style1__content">
                    <?php echo do_shortcode($settings['mailchimp_form_url']); ?>
                </div>
            </div>
        </div>
        <?php } ?>
    </section>
    <!--End Subscribe Style2-->
    
	<?php elseif($layout == '4') : ?>
    
    <!--Start Scrolling Text Style5 -->
    <section class="scrolling-text-style5">
        <?php if($settings['title']){ ?>
        <div class="scrolling-text-style5__title">
            <h6><?php echo wp_kses($settings['title'], true); ?></h6>
        </div>
		<?php } ?>
        
		<?php
        	$features_list = $settings['features_list'];
			if(!empty($features_list)){
			$features_list = explode("\n", ($features_list)); 
		?>
        <div class="inner">
            <ul class="clearfix marquee_mode">
                <?php foreach($features_list as $features){ ?>
                <li data-hover="<?php echo esc_attr($features); ?>">
                	<?php echo wp_kses($features, true); ?>
                </li> 
                <?php } ?>               
            </ul>
        </div>
        <?php } ?>
        
        <?php if($settings['show_marquee_text_v2'] == 'yes'){ ?>
        <?php if($settings['pattern_img_v1']){ ?>
        <div class="pattern-box">
            <div class="pattern-box__bg" style="background-image: url(<?php echo esc_url(wp_get_attachment_url($settings['pattern_img_v1']['id'])); ?>);"></div>
        </div>
        <?php } ?>
        <?php if($settings['title_v2']){ ?>
        <div class="scrolling-text-style5__title scrolling-text-style5__title--style2">
            <h6><?php echo wp_kses($settings['title_v2'], true); ?></h6>
        </div>
        <?php } ?>
        
        <?php 
			$features_list = $settings['features_list_v2'];
			if(!empty($features_list)){
			$features_list = explode("\n", ($features_list)); 
		?>
        <div class="inner">
            <ul class="clearfix marquee_mode-language">
                <?php foreach($features_list as $features){ ?>
                <li data-hover="<?php echo esc_attr($features); ?>">
                	<?php echo wp_kses($features, true); ?>
                </li> 
                <?php } ?>
            </ul>
        </div>
        <?php } ?>
		<?php } ?>
        
        <?php if($settings['show_marquee_text_v3'] == 'yes'){ ?>
        <?php if($settings['pattern_img_v2']){ ?>
        <div class="pattern-box">
            <div class="pattern-box__bg pattern-box__bg--style2"
                style="background-image: url(<?php echo esc_url(wp_get_attachment_url($settings['pattern_img_v2']['id'])); ?>);">
            </div>
        </div>
        <?php } ?>
        <?php if($settings['title_v3']){ ?>
        <div class="scrolling-text-style5__title scrolling-text-style5__title--style2">
            <h6><?php echo wp_kses($settings['title_v3'], true); ?></h6>
        </div>
        <?php } ?>
        
        <?php 
			$features_list = $settings['features_list_v3'];
			if(!empty($features_list)){
			$features_list = explode("\n", ($features_list)); 
		?>
        <div class="inner">
            <ul class="clearfix marquee_mode">
                <?php foreach($features_list as $features){ ?>
                <li data-hover="<?php echo esc_attr($features); ?>">
                	<?php echo wp_kses($features, true); ?>
                </li> 
                <?php } ?>
            </ul>
        </div>
		<?php } ?>
		<?php } ?>
    </section>
    <!--End Scrolling Text Style5 -->
    
    <?php elseif($layout == '3') : ?>
	
	<!--Start Scrolling Text Style1-->
    <section class="scrolling-text-style1 scrolling-text-style1--style3">
        <div class="inner">
            <ul class="clearfix marquee_mode">
                <?php 
					foreach ($settings['list'] as $keys => $items){
					
					$features_list = $items['features_list'];
					if(!empty($features_list)){
					$features_list = explode("\n", ($features_list)); 
				?>
                <li class="is-animetion is-animetion-style3">
                    <?php foreach($features_list as $features): ?>
                    <span><?php echo wp_kses($features, true); ?></span>
                    <?php endforeach; ?>
                </li>
                <?php } } ?>
            </ul>
        </div>
    </section>
    <!--End Scrolling Text Style1-->
	
	<?php elseif($layout == '2') : ?>
    
    <!--Start Scrolling Text Style1-->
    <section class="scrolling-text-style1 scrolling-text-style1--style2">
        <div class="inner">
            <ul class="clearfix marquee_mode">
                <?php 
					foreach ($settings['list'] as $keys => $items){
					
					$features_list = $items['features_list'];
					if(!empty($features_list)){
					$features_list = explode("\n", ($features_list)); 
				?>
                <li class="is-animetion is-animetion-style2">
                    <?php foreach($features_list as $features): ?>
                    <span><?php echo wp_kses($features, true); ?></span>
                    <?php endforeach; ?>
                </li>
                <?php } } ?>
            </ul>
        </div>
    </section>
    <!--End Scrolling Text Style1-->
    
    <?php else: ?>
    
    <!--Start Scrolling Text Style1-->
    <section class="scrolling-text-style1">
        <div class="inner">
            <ul class="clearfix marquee_mode">
                <?php 
					foreach ($settings['list'] as $keys => $items){
					
					$features_list = $items['features_list'];
					if(!empty($features_list)){
					$features_list = explode("\n", ($features_list)); 
				?>
                <li class="is-animetion">
                    <?php foreach($features_list as $features): ?>
                    <span><?php echo wp_kses($features, true); ?></span>
                    <?php endforeach; ?>
                </li>
                <?php } } ?>                
            </ul>
        </div>
    </section>
    <!--End Scrolling Text Style1-->
    <?php endif; ?>
    
	<?php
    }
}
