<?php namespace THINKAIPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Text_Stroke;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Video_Banner extends Widget_Base {

    /**
     * Get widget name.
     * Retrieve button widget name.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name() {
        return 'thinkai_video_banner';
    }

    /**
     * Get widget title.
     * Retrieve button widget title.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Thinkai Video Banner', 'thinkai' );
    }

    /**
     * Get widget icon.
     * Retrieve button widget icon.
     *
     * @since  1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-gallery-grid';
    }

    /**
     * Get widget categories.
     * Retrieve the list of categories the button widget belongs to.
     * Used to determine where to display the widget in the editor.
     *
     * @since  2.0.0
     * @access public
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'thinkai' ];
    }
	
	public function get_script_depends() {
		wp_register_script( 'video-banner-script', YT_URL . 'assets/js/video-banner.js', [ 'elementor-frontend' ], '1.0.0', true );
		return [ 'video-banner-script' ];
	}
	
    /**
     * Register button widget controls.
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(    
            'video_banner',
            [
                'label' => esc_html__( 'Thinkai Video Banner', 'thinkai' ),
            ]
        );	
		
		$this->add_control(
			'layout_control',
			[
				'label'   => esc_html__( 'Layout Style', 'thinkai' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => array(
					'1' => esc_html__( 'Style One ', 'thinkai'),
					'2' => esc_html__( 'Style Two ', 'thinkai'),
				),
			]
		);
		
		$this->add_control(
			'video_img',
			[
				'label' => __( 'Video Image', 'thinkai' ),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
				'condition' => [
					'layout_control'      => '2',
				],
			]
		);
		
		//Video Link Option			
		$this->add_control(
			'video_option',
			[
				'label' => __( 'Select Video Type', 'thinkai' ),
				'label_block' => true, 
				'type' => Controls_Manager::SELECT,
				'default' => 'src_url',
				'options' => array(
					'src_url'       => esc_html__( 'Source URL', 'thinkai' ),
					'src_media'      => esc_html__( 'Source Media', 'thinkai' ),
				),
			]
		);
		$this->add_control(
            'video_link',
			[
				'label' => __( 'Video Source Url', 'thinkai' ),
				'type' => Controls_Manager::URL,
				'label_block' => true, 
				'placeholder' => __( 'https://your-link.com', 'thinkai' ),
				'show_external' => true,
				'default' => [
					'url' => '',
				],
				'condition' => [
					'video_option'      => 'src_url'
				],
			]
		);
		$this->add_control(
			'video_source_image',
			[
				'label' => __( 'Video Source Media', 'thinkai' ),
				'type' => Controls_Manager::MEDIA,
				'media_types' => ['video'],
				'condition' => [
					'video_option'      => 'src_media'
				],
			]
		);
		
		//Title
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'thinkai' ),
				'type'        => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'default' => esc_html__( 'Image Generator', 'thinkai' ),
			]
		);
		//Text
		$this->add_control(
			'text',
			[
				'label'       => __( 'Description', 'thinkai' ),
				'type'        => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'default' => esc_html__( 'Convert text to image.', 'thinkai' ),
				'condition' => [
					'layout_control'      => '1',
				],
			]
		);
		
		//Button Title
		$this->add_control(
			'btn_title',
			[
				'label'       => __( 'Button Title', 'thinkai' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'dynamic'     => [
					'active' => true,
				],
				'default' => esc_html__( 'Try a Template', 'thinkai' ),
				'condition' => [
					'layout_control'      => '1',
				],
			]
		);
		$this->add_control(
			'link_option',
			[
				'label'   => esc_html__( 'Select link Option', 'thinkai' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT,
				'default' => 'extranal',
				'options' => array(
					'extranal' => esc_html__( 'Extranal ', 'thinkai'),
					'page' => esc_html__( 'Page ', 'thinkai'),
				),
				'condition' => [
					'layout_control'      => '1',
				],
			]
		);		
		$this->add_control(
			'link',
			[
				'label' => __( 'External Link', 'thinkai' ),
				'type' => Controls_Manager::URL,
				'label_block' => true, 
				'placeholder' => __( 'https://your-link.com', 'thinkai' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
				'condition'   => [
					'layout_control'      => '1',
					'link_option' => 'extranal'
				]
			]
		);		
		$this->add_control(
			'page_select',
			[
				'label'   => esc_html__( 'Select Page', 'thinkai' ),
				'label_block' => true,
				'type'    => Controls_Manager::SELECT2,
				'default' => 'extranal',
				'options' => thinkai_page_list(),
				'condition'   => [
					'layout_control'      => '1',
					'link_option' => 'page'
				]
			]
		);
		
		//Switcher
		$this->add_control(
            'show_email_info',
            [
                'label'        => esc_html__( 'Enable Email Info', 'thinkai' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'thinkai' ),
                'label_off'    => esc_html__( 'Off', 'thinkai' ),
                'return_value' => 'yes',
                'default'      => 'no',
				'condition' => [
					'layout_control'      => '1',
				],
            ]
        );
		$this->add_control(
			'email_title',
			[
				'label' => esc_html__( 'Email Title', 'thinkai' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'default' => esc_html__( 'Have Question?', 'thinkai' ),
				'condition'   => [ 
					'layout_control'      => '1',
					'show_email_info' => 'yes' 
				]
			]
		);
		$this->add_control(
			'email_address',
			[
				'label' => esc_html__( 'Email Address', 'thinkai' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'default' => esc_html__( 'info@example.com', 'thinkai' ),
				'condition'   => [ 
					'layout_control'      => '1',
					'show_email_info' => 'yes' 
				]
			]
		);		
		$this->end_controls_section();
	
		
			
    }

    /**
     * Render button widget output on the frontend.
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $allowed_tags = wp_kses_allowed_html('post');
		$layout = $settings[ 'layout_control' ];
		
		$video_option = $settings[ 'video_option' ];
		if( $video_option == 'src_url' ){
			$video = $settings[ 'video_link' ][ 'url' ];
		}elseif( $video_option == 'src_media' ){
			$video = $settings[ 'video_source_image' ]['url'];
		}else{
			$video = esc_html__( 'There is no Video', 'thinkai' );
		}
		
	?>
	
    <?php 
		if($layout == '2') :
	?>
    
    <div class="service-details-video-holder">
        <div class="service-details-video-holder__bg"
            style="background-image: url(<?php echo esc_url(wp_get_attachment_url($settings['video_img']['id'])); ?>);">
        </div>
        
		<?php if($settings['title']){ ?>
        <div class="overlay-title">
            <h4><?php echo wp_kses($settings['title'], true); ?></h4>
        </div>
        <?php } ?>
        
		<?php if($video){ ?>
        <div class="icon wow zoomIn animated" data-wow-delay="300ms" data-wow-duration="1500ms">
            <a class="video-popup" title="Video Gallery"
                href="<?php echo esc_url( $video );?>">
                <span class="icon-play-button-arrowhead"></span>
            </a>
        </div>
        <?php } ?>
    </div>
    
    <?php else: 
		$page = $settings['link_option'];
		$page_select = $settings[ 'page_select' ];
		$ext_url = $settings[ 'link' ];
		
		if( $page == 'page' ){
			$mount_link = get_page_link( $page_select );
		}else{
			$mount_link = $ext_url['url'];
			$target = $ext_url['is_external'] ? ' target="_blank"' : '';
			$nofollow = $ext_url['nofollow'] ? ' rel="nofollow"' : '';
		}
	?>
    
    <!-- Start Video Banner Style1 -->
    <div class="video-banner-style1 full-height">
        <div class="video-banner-style1__inner">
            <?php if($video){ ?>
            <div class="media-container" data-top-bottom="transform: translateY(300px);"
                data-bottom-top="transform: translateY(-300px);">
                <div class="video-holder-wrap fs-wrapper">
                    <div class="video-container">
                        <video autoplay playsinline loop muted class="bgvid">
                            <source src="<?php echo esc_url( $video );?>" type="video/mp4">
                        </video>
                    </div>
                </div>
            </div>
            <?php } ?>
            <div class="overlay"></div>
            <div class="video-banner-style1__content">
                <div class="video-banner-style1__content-inner">
                    <div class="big-title">
                        <?php if($settings['title']){ ?>
                        <h2><?php echo wp_kses($settings['title'], true); ?></h2>
                        <?php } ?>
                        
						<?php if($settings['btn_title']){ ?>
                        <a class="btn1" href="<?php echo esc_url( $mount_link );?>" <?php if( $page == 'extranal' ) echo esc_attr( $target );?> <?php if( $page == 'extranal' ) echo esc_attr( $nofollow );?>>
                            <span class="icon-right-arrow1"></span><?php echo wp_kses($settings['btn_title'], true);?>
                        </a>
                        <?php } ?>
                    </div>
                    <?php if($settings['text']){ ?>
                    <div class="text">
                        <div class="border-box"></div>
                        <p><?php echo wp_kses($settings['text'], true); ?></p>
                    </div>
                    <?php } ?>
                </div>
            </div>
			<?php if($settings['show_email_info'] == 'yes'){ ?>
            <div class="video-banner-style1__content-info">
                <div class="video-banner-style1__content-info-inner">
                    <div class="icon-box">
                        <span class="icon-email-1"></span>
                    </div>
                    <div class="text">
                        <h5><?php echo wp_kses($settings['email_title'], true); ?></h5>
                        <a href="mailto:<?php echo esc_attr($settings['email_address']); ?>"><?php echo wp_kses($settings['email_address'], true); ?></a>
                    </div>
                </div>
            </div>
			<?php } ?>
        </div>
    </div>
    <!-- End Video Banner Style1 -->
    
	<?php endif;
    }
}
